@@ -21,9 +21,9 @@ class PacketOrderer:
 
     def start(self):
         """Initializes the packet orderer"""
-        self._sequenceNumberByAccount = {}
+        self._sequenceNumberByInstance = {}
         self._lastSessionStartTimestamp = {}
-        self._packetsByAccountId = {}
+        self._packetsByInstance = {}
 
         async def emit_events():
             while True:
@@ -45,39 +45,42 @@ class PacketOrderer:
             packet: Packet to process.
 
         """
+        instance_id = packet['accountId'] + ':' + str(packet['instanceIndex'] if 'instanceIndex' in packet else 0)
         if 'sequenceNumber' not in packet:
             return [packet]
         if packet['type'] == 'synchronizationStarted' and 'synchronizationId' in packet:
             # synchronization packet sequence just started
-            self._isOutOfOrderEmitted[packet['accountId']] = False
-            self._sequenceNumberByAccount[packet['accountId']] = packet['sequenceNumber']
-            self._lastSessionStartTimestamp[packet['accountId']] = packet['sequenceTimestamp']
-            self._packetsByAccountId[packet['accountId']] = \
+            self._isOutOfOrderEmitted[instance_id] = False
+            self._sequenceNumberByInstance[instance_id] = packet['sequenceNumber']
+            self._lastSessionStartTimestamp[instance_id] = packet['sequenceTimestamp']
+            self._packetsByInstance[instance_id] = \
                 list(filter(lambda wait_packet: wait_packet['packet']['sequenceTimestamp'] >=
                             packet['sequenceTimestamp'],
-                            (self._packetsByAccountId[packet['accountId']] if packet['accountId'] in
-                             self._packetsByAccountId else [])))
-            return [packet] + self._find_next_packets_from_wait_list(packet['accountId'])
-        elif packet['accountId'] in self._lastSessionStartTimestamp and \
-                packet['sequenceTimestamp'] < self._lastSessionStartTimestamp[packet['accountId']]:
+                            (self._packetsByInstance[instance_id] if instance_id in
+                             self._packetsByInstance else [])))
+            return [packet] + self._find_next_packets_from_wait_list(instance_id)
+        elif instance_id in self._lastSessionStartTimestamp and \
+                packet['sequenceTimestamp'] < self._lastSessionStartTimestamp[instance_id]:
             # filter out previous packets
             return []
-        elif packet['accountId'] in self._sequenceNumberByAccount and \
-                packet['sequenceNumber'] == self._sequenceNumberByAccount[packet['accountId']]:
+        elif instance_id in self._sequenceNumberByInstance and \
+                packet['sequenceNumber'] == self._sequenceNumberByInstance[instance_id]:
             # let the duplicate s/n packet to pass through
             return [packet]
-        elif packet['accountId'] in self._sequenceNumberByAccount and \
-                packet['sequenceNumber'] == self._sequenceNumberByAccount[packet['accountId']] + 1:
+        elif instance_id in self._sequenceNumberByInstance and \
+                packet['sequenceNumber'] == self._sequenceNumberByInstance[instance_id] + 1:
             # in-order packet was received
-            self._sequenceNumberByAccount[packet['accountId']] += 1
-            return [packet] + self._find_next_packets_from_wait_list(packet['accountId'])
+            self._sequenceNumberByInstance[instance_id] += 1
+            return [packet] + self._find_next_packets_from_wait_list(instance_id)
         else:
             # out-of-order packet was received, add it to the wait list
-            self._packetsByAccountId[packet['accountId']] = self._packetsByAccountId[packet['accountId']] \
-                if packet['accountId'] in self._packetsByAccountId else []
-            wait_list = self._packetsByAccountId[packet['accountId']]
+            self._packetsByInstance[instance_id] = self._packetsByInstance[instance_id] \
+                if instance_id in self._packetsByInstance else []
+            wait_list = self._packetsByInstance[instance_id]
             wait_list.append({
+                'instanceId': instance_id,
                 'accountId': packet['accountId'],
+                'instanceIndex': packet['instanceIndex'] if 'instanceIndex' in packet else 0,
                 'sequenceNumber': packet['sequenceNumber'],
                 'packet': packet,
                 'receivedAt': datetime.now()
@@ -87,29 +90,30 @@ class PacketOrderer:
                 wait_list.pop(0)
             return []
 
-    def _find_next_packets_from_wait_list(self, account_id) -> List:
+    def _find_next_packets_from_wait_list(self, instance_id) -> List:
         result = []
-        wait_list = self._packetsByAccountId[account_id] if account_id in self._packetsByAccountId else []
-        while len(wait_list) and wait_list[0]['sequenceNumber'] in [self._sequenceNumberByAccount[account_id],
-                                                                    self._sequenceNumberByAccount[account_id] + 1]:
+        wait_list = self._packetsByInstance[instance_id] if instance_id in self._packetsByInstance else []
+        while len(wait_list) and wait_list[0]['sequenceNumber'] in [self._sequenceNumberByInstance[instance_id],
+                                                                    self._sequenceNumberByInstance[instance_id] + 1]:
             result.append(wait_list[0]['packet'])
-            if wait_list[0]['sequenceNumber'] == self._sequenceNumberByAccount[account_id] + 1:
-                self._sequenceNumberByAccount[account_id] += 1
+            if wait_list[0]['sequenceNumber'] == self._sequenceNumberByInstance[instance_id] + 1:
+                self._sequenceNumberByInstance[instance_id] += 1
             wait_list.pop(0)
-        if not len(wait_list) and account_id in self._packetsByAccountId:
-            del self._packetsByAccountId[account_id]
+        if not len(wait_list) and instance_id in self._packetsByInstance:
+            del self._packetsByInstance[instance_id]
         return result
 
     def _emit_out_of_order_events(self):
-        for key, wait_list in self._packetsByAccountId.items():
+        for key, wait_list in self._packetsByInstance.items():
             if len(wait_list) and \
                     (wait_list[0][
                          'receivedAt'].timestamp() + self._orderingTimeoutInSeconds) < datetime.now().timestamp():
-                account_id = wait_list[0]['accountId']
-                if account_id not in self._isOutOfOrderEmitted or not self._isOutOfOrderEmitted[account_id]:
-                    self._isOutOfOrderEmitted[account_id] = True
+                instance_id = wait_list[0]['instanceId']
+                if instance_id not in self._isOutOfOrderEmitted or not self._isOutOfOrderEmitted[instance_id]:
+                    self._isOutOfOrderEmitted[instance_id] = True
                     # Do not emit onOutOfOrderPacket for packets that come before synchronizationStarted
-                    if account_id in self._sequenceNumberByAccount:
+                    if instance_id in self._sequenceNumberByInstance:
                         asyncio.create_task(self._outOfOrderListener.on_out_of_order_packet(
-                            wait_list[0]['accountId'], self._sequenceNumberByAccount[account_id] + 1,
+                            wait_list[0]['accountId'], wait_list[0]['instanceIndex'],
+                            self._sequenceNumberByInstance[instance_id] + 1,
                             wait_list[0]['sequenceNumber'], wait_list[0]['packet'], wait_list[0]['receivedAt']))
